
CREATE TABLE IF NOT EXISTS `document` (
    `id` bigint NOT NULL AUTO_INCREMENT,
    `_model` varchar(50)  COMMENT '模型',
    `name` VARCHAR(200)  COMMENT '名称',
    `summary` text COMMENT '概要',
    `content` longtext COMMENT '内容',
    `slug` varchar(200) COMMENT 'Slug',
    `parent_id` bigint  COMMENT '父级',
    `cover_id` bigint COMMENT '缩略图',
    `category_id` bigint COMMENT '分类',
    `sort` int NOT NULL DEFAULT '100' COMMENT '排序',
    `flag` varchar(50) COMMENT '标识',
    `mime` varchar(100)  NOT NULL DEFAULT '' COMMENT 'MimeType',
    `user_id` bigint,
    `status` varchar(20) NOT NULL DEFAULT 'normal' COMMENT '状态',
    `publish_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '发布时间',
    `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    KEY `ind_slug` (`slug`(50)),
    KEY `ind_flag` (`flag`(50)),
    KEY `ind_model_status` (`_model`,`status`,`publish_at`),
    KEY `ind_parent_id` (`parent_id`),
    KEY `ind_user_id` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `document_attr` (
   `id` bigint NOT NULL AUTO_INCREMENT,
   `fk` bigint NOT NULL,
   `name` varchar(200) NOT NULL,
   `value` longtext,
    PRIMARY KEY (`id`),
    KEY `ind_fk` (`fk`,`name`(20)),
    KEY `ind_name` (`name`(20),`value`(20))
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `term` (
    `id` bigint NOT NULL AUTO_INCREMENT,
    `_model` varchar(50),
    `name` varchar(200),
    `slug` varchar(200),
    `sort` int NOT NULL DEFAULT '100' COMMENT '排序',
    `flag` varchar(50) COMMENT '标识',
    `status` varchar(20)  NOT NULL DEFAULT 'normal',
    `description` longtext,
    `parent_id` bigint ,
    `user_id` bigint,
    `count` bigint NOT NULL DEFAULT '0',
    `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    KEY `ind_slug` (`slug`(50)),
    KEY `ind_name` (`name`(50)),
    KEY `ind_model` (`_model`, `status`)
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4 COMMENT '术语';

CREATE TABLE IF NOT EXISTS `term_attr` (
   `id` bigint NOT NULL AUTO_INCREMENT,
   `fk` bigint NOT NULL,
   `name` varchar(200) NOT NULL,
   `value` longtext,
    PRIMARY KEY (`id`),
    KEY `ind_fk` (`fk`,`name`(20)),
    KEY `ind_name` (`name`(20), `value`(20))
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `document_term` (
    `document_id` bigint NOT NULL,
    `term_id` bigint NOT NULL,
    PRIMARY KEY (document_id, `term_id`),
    KEY (`term_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `option` (
    `id` bigint NOT NULL AUTO_INCREMENT,
    `name` varchar(200) NOT NULL,
    `value` longtext,
    PRIMARY KEY (`id`),
    UNIQUE KEY `ind_name` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4 COMMENT '配置';

CREATE TABLE IF NOT EXISTS `user`(
    `id` bigint AUTO_INCREMENT PRIMARY KEY,
    `account` VARCHAR(50) COMMENT '登录帐号',
    `password_hash` VARCHAR(255) COMMENT '密码',
    `password_salt` varchar(50),
    `name` VARCHAR(255) COMMENT '名字',
    `email` VARCHAR(255) COMMENT '邮箱',
    `mobile` VARCHAR(50) COMMENT '手机',
    `status` varchar(20) NOT NULL DEFAULT 'normal' COMMENT '状态',
    `change_password_at` datetime COMMENT '修改密码时间',
    `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    KEY ind_account (account(20)),
    KEY ind_email (email(20)),
    KEY ind_mobile ( mobile)
)ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4 COMMENT '用户';

CREATE TABLE IF NOT EXISTS `user_attr` (
    `id` bigint NOT NULL AUTO_INCREMENT,
    `fk` bigint NOT NULL,
    `name` varchar(200) NOT NULL,
    `value` longtext,
    PRIMARY KEY (`id`),
    KEY `ind_fk` (`fk`,`name`(20)),
    KEY `ind_name` (`name`(20),`value`(20))
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `record` (
    `id` BIGINT AUTO_INCREMENT PRIMARY KEY,
    `_model` varchar(50),
    `user_id` bigint ,
    `parent_id` bigint,
    `guid` VARCHAR(50) UNIQUE COMMENT '序号',
    `sort` int NOT NULL DEFAULT '100' COMMENT '排序',
    `category_id` bigint  COMMENT '分类',
    `name` VARCHAR(200)  COMMENT '名称',
    `flag` varchar(50)  COMMENT '标识',
    `code` varchar(32)  COMMENT '编码',
    `quantity` INT COMMENT '数量',
    `amount` DECIMAL(10,2) COMMENT '金额',
    `summary` text COMMENT '概要',
    `content` longtext COMMENT '内容',
    `status` varchar(20) NOT NULL DEFAULT 'normal' COMMENT '状态',
    `created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    KEY ind_user_id(_model,user_id,flag)
)ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 AUTO_INCREMENT=1001;

CREATE TABLE IF NOT EXISTS `record_attr` (
    `id` bigint NOT NULL AUTO_INCREMENT,
    `fk` bigint NOT NULL,
    `name` varchar(200) NOT NULL,
    `value` longtext,
    PRIMARY KEY (`id`),
    KEY `ind_fk` (`fk`,`name`(20)),
    KEY `ind_name` (`name`(20),`value`(20))
) ENGINE=InnoDB AUTO_INCREMENT=1001 DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `task`  (
    `id` BIGINT NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `name` VARCHAR(100) NOT NULL COMMENT '任务名称',
    `code` VARCHAR(100) NOT NULL COMMENT '任务识别码',
    `status` varchar(20) NOT NULL DEFAULT 'normal' COMMENT '状态',
    `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`) ,
    KEY `ind_code`(`code`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COMMENT='任务';

CREATE TABLE IF NOT EXISTS `role`  (
    `id` BIGINT NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `name` VARCHAR(50) NOT NULL COMMENT '名称',
    `code` VARCHAR(50) NOT NULL COMMENT '识别码',
    `spec` VARCHAR(200) COMMENT '说明',
    `sort` INT DEFAULT 100 COMMENT '排序',
    `status` varchar(20) NOT NULL DEFAULT 'normal' COMMENT '状态',
    `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COMMENT='角色';

CREATE TABLE IF NOT EXISTS `role_task` (
    `id` BIGINT NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `role_id` BIGINT NOT NULL COMMENT '角色',
    `task_id` BIGINT NOT NULL COMMENT '角色',
    `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`) ,
    KEY `ind_role_task`(`role_id`, `task_id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COMMENT='角色权限';

CREATE TABLE IF NOT EXISTS `role_user` (
    `id` BIGINT NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `user_id` BIGINT NOT NULL COMMENT '用户',
    `role_id` BIGINT NOT NULL COMMENT '角色',
    `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    KEY `ind_user_id`(`user_id`),
    KEY `ind_role_id`(`role_id`)
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COMMENT='用户角色';


INSERT INTO `term` (`id`, `_model`, `name`, `slug`, `sort`, `flag`, `status`, `description`, `parent_id`, `user_id`)
VALUES
(1, 'adminMenu', '文章管理', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(2, 'adminMenu', '网站设置', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(3, 'adminMenu', '文章', '/document/article', 100, NULL, 'normal', NULL, 1, NULL),
(4, 'adminMenu', '分类', '/document/category', 100, NULL, 'normal', NULL, 1, NULL),
(5, 'adminMenu', '页面', '/document/page', 100, NULL, 'normal', NULL, 2, NULL),
(6, 'adminMenu', '导航', '/document/menu', 100, NULL, 'normal', NULL, 2, NULL),
(7, 'adminMenu', '广告', '/document/banner', 100, NULL, 'normal', NULL, 2, NULL),
(8, 'adminMenu', '推荐位', '/document/position', 100, NULL, 'normal', NULL, 2, NULL),
(1001, 'category', '博客', '', 100, NULL, 'normal', NULL, 0, NULL),
(1002, 'menu', '关于', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(1003, 'menu', '博客', NULL, 1, NULL, 'normal', NULL, 0, NULL);

INSERT INTO `term_attr` (`id`, `fk`, `name`, `value`)
VALUES
(1001, 1002, 'menu_type', 'page'),
(1002, 1002, 'menu_detail', '1002'),
(1003, 1003, 'menu_type', 'category'),
(1004, 1003, 'menu_detail', '1001');


INSERT INTO `document` (`id`, `_model`, `name`, `summary`, `content`, `slug`, `parent_id`, `cover_id`, `category_id`, `sort`, `flag`, `mime`, `user_id`, `status`, `publish_at`)
VALUES
(1001, 'article', '你好 CPress！', NULL, '<p>欢迎使用 CPress！</p><p>这是一篇自动生成的内容，你可以到管理后台编辑或删除。</p>', NULL, NULL, NULL, 1001, 100, NULL, '', 1, 'normal', now()),
(1002, 'page', '关于', NULL, '<p>一个使用 CPress 构建的网站！</p>', NULL, 0, NULL, NULL, 100, NULL, '', NULL, 'normal', now());



INSERT INTO `user` (`id`, `account`, `password_hash`, `password_salt`, `name`, `status`)
VALUES
(1, 'admin', md5('cpress'), '', 'Admin', 'normal');
