
CREATE TABLE IF NOT EXISTS `document` (
`id` INTEGER  PRIMARY KEY AUTOINCREMENT,
`_model` varchar(50),
`name` VARCHAR(200),
`summary` text,
`content` longtext,
`slug` varchar(200),
`parent_id` bigint,
`cover_id` bigint,
`category_id` bigint,
`sort` int NOT NULL DEFAULT '100',
`flag` varchar(50),
`mime` varchar(100)  NOT NULL DEFAULT '' ,
`user_id` bigint,
`status` varchar(20) NOT NULL DEFAULT 'normal',
`publish_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
`created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE INDEX  `ind_document_slug` ON `document` (`slug`);
CREATE INDEX  `ind_document_flag` ON `document` (`flag`);
CREATE INDEX  `ind_document_model_status` ON `document`  (`_model`,`status`,`publish_at`);
CREATE INDEX  `ind_document_parent_id` ON `document` (`parent_id`);
CREATE INDEX  `ind_document_user_id` ON `document` (`user_id`);


CREATE TABLE `document_attr` (
`id` INTEGER PRIMARY KEY AUTOINCREMENT ,
`fk` INTEGER NOT NULL,
`name` varchar(200) NOT NULL,
`value` longtext
);

CREATE INDEX `ind_document_attr_fk` ON document_attr (`fk`,`name`);
CREATE INDEX `ind_document_attr_name` ON document_attr  (`name`);


CREATE TABLE IF NOT EXISTS `term` (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`_model` varchar(50) ,
`name` varchar(200) ,
`slug` varchar(200),
`sort` int NOT NULL DEFAULT '100',
`flag` varchar(50),
`status` varchar(20)  NOT NULL DEFAULT 'normal',
`description` longtext,
`parent_id` bigint ,
`user_id` bigint,
`count` bigint NOT NULL DEFAULT '0',
`created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE  INDEX `ind_term_slug` ON `term` (`slug`);
CREATE  INDEX `ind_term_name` ON `term` (`name`);
CREATE  INDEX `ind_term_model` ON `term` (`_model`,`status`);


CREATE TABLE `term_attr` (
`id` INTEGER  PRIMARY KEY AUTOINCREMENT,
`fk` INTEGER NOT NULL,
`name` varchar(200) NOT NULL,
`value` longtext
);

CREATE INDEX `ind_term_attr_fk` ON term_attr (`fk`,`name`);
CREATE INDEX `ind_term_attr_name` ON term_attr  (`name`);


CREATE TABLE IF NOT EXISTS `document_term` (
`document_id` bigint NOT NULL,
`term_id` bigint NOT NULL,
PRIMARY KEY (document_id, `term_id`)
);

CREATE INDEX `ind_document_term_id` ON `document_term` (`term_id`);


CREATE TABLE `option` (
`id` INTEGER  PRIMARY KEY AUTOINCREMENT,
`name` varchar(200) NOT NULL DEFAULT '',
`value` longtext
);
CREATE INDEX `ind_option_name` ON `option` (`name`);


CREATE TABLE IF NOT EXISTS `user`(
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
account VARCHAR(50),
password_hash VARCHAR(255),
password_salt varchar(50),
name VARCHAR(255),
email VARCHAR(255),
mobile VARCHAR(50),
status varchar(20) NOT NULL DEFAULT 'normal',
`change_password_at` datetime,
`created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE INDEX `ind_user_account` ON `user`  (`account`);
CREATE INDEX `ind_user_email` ON `user`  (`email`);
CREATE INDEX `ind_user_mobile` ON `user`  (`mobile`);


CREATE TABLE `user_attr` (
`id` INTEGER  PRIMARY KEY AUTOINCREMENT,
`fk` INTEGER NOT NULL,
`name` varchar(200) NOT NULL,
`value` longtext
);

CREATE INDEX `ind_user_attr_fk` ON user_attr (`fk`,`name`);
CREATE INDEX `ind_user_attr_name` ON user_attr  (`name`);


CREATE TABLE IF NOT EXISTS `task`  (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`name` VARCHAR(100) NOT NULL,
`code` VARCHAR(100) NOT NULL,
status varchar(20) NOT NULL DEFAULT 'normal',
`created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP
);
CREATE INDEX `ind_task_code` ON task  (`code`);


CREATE TABLE IF NOT EXISTS `role`  (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`name` VARCHAR(50) NOT NULL,
`code` VARCHAR(50) NOT NULL,
`spec` VARCHAR(200),
`sort` INT DEFAULT 100,
status varchar(20) NOT NULL DEFAULT 'normal',
`created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP
);
CREATE INDEX `ind_role_code` ON role  (`code`);


CREATE TABLE IF NOT EXISTS `role_task`  (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`role_id` BIGINT NOT NULL,
`task_id` BIGINT NOT NULL,
`created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP
);
CREATE UNIQUE INDEX `ind_role_task` ON role_task  (`role_id`, `task_id`);


CREATE TABLE IF NOT EXISTS `role_user`  (
`id` INTEGER PRIMARY KEY AUTOINCREMENT,
`user_id` BIGINT NOT NULL,
`role_id` BIGINT NOT NULL,
`created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
`updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP
);

CREATE UNIQUE INDEX `ind_role_user` ON role_user  (`user_id`, `role_id`);


INSERT INTO `term` (`id`, `_model`, `name`, `slug`, `sort`, `flag`, `status`, `description`, `parent_id`, `user_id`)
VALUES
(1, 'adminMenu', '文章管理', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(2, 'adminMenu', '网站设置', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(3, 'adminMenu', '文章', '/document/article', 100, NULL, 'normal', NULL, 1, NULL),
(4, 'adminMenu', '分类', '/document/category', 100, NULL, 'normal', NULL, 1, NULL),
(5, 'adminMenu', '页面', '/document/page', 100, NULL, 'normal', NULL, 2, NULL),
(6, 'adminMenu', '导航', '/document/menu', 100, NULL, 'normal', NULL, 2, NULL),
(7, 'adminMenu', '广告', '/document/banner', 100, NULL, 'normal', NULL, 2, NULL),
(8, 'adminMenu', '推荐位', '/document/position', 100, NULL, 'normal', NULL, 2, NULL),
(1001, 'category', '博客', '', 100, NULL, 'normal', NULL, 0, NULL),
(1002, 'menu', '关于', NULL, 100, NULL, 'normal', NULL, 0, NULL),
(1003, 'menu', '博客', NULL, 1, NULL, 'normal', NULL, 0, NULL);

INSERT INTO `term_attr` (`id`, `fk`, `name`, `value`)
VALUES
(1001, 1002, 'menu_type', 'page'),
(1002, 1002, 'menu_detail', '1002'),
(1003, 1003, 'menu_type', 'category'),
(1004, 1003, 'menu_detail', '1001');

INSERT INTO `document` (`id`, `_model`, `name`, `summary`, `content`, `slug`, `parent_id`, `cover_id`, `category_id`, `sort`, `flag`, `mime`, `user_id`, `status`, `publish_at`)
VALUES
(1001, 'article', '你好 CPress！', NULL, '<p>欢迎使用 CPress！</p><p>这是一篇自动生成的内容，你可以到管理后台编辑或删除。</p>', NULL, NULL, NULL, 1001, 100, NULL, '', 1, 'normal', datetime()),
(1002, 'page', '关于', NULL, '<p>一个使用 CPress 构建的网站！</p>', NULL, 0, NULL, NULL, 100, NULL, '', NULL, 'normal', datetime());

INSERT INTO `user` (`id`, `account`, `password_hash`, `password_salt`, `name`, `status`)
VALUES
(1, 'admin', 'f28eba46c7870ea05115ee3a91589e7e', '', 'Admin', 'normal');

